@@ -17,8 +17,8 @@ package PostScript::ScheduleGrid;
 # ABSTRACT: Print a schedule in a grid format
 #---------------------------------------------------------------------
 
-our $VERSION = '0.03';
-# This file is part of PostScript-ScheduleGrid 0.03 (May 11, 2013)
+our $VERSION = '0.04';
+# This file is part of PostScript-ScheduleGrid 0.04 (December 7, 2013)
 
 use 5.010;
 use Moose;
@@ -27,12 +27,12 @@ use MooseX::Types::Moose qw(ArrayRef Bool HashRef Int Num Str);
 use MooseX::Types::DateTime (); # Just load coercions
 use PostScript::ScheduleGrid::Types ':all';
 
-use Class::MOP ();              # for load_class
 use DateTime ();
 use DateTime::TimeZone ();
 use List::Util 1.20 qw(max min); # support overloaded comparisons
+use Module::Runtime qw( require_module );
 use POSIX qw(floor);
-use PostScript::File 2.11 qw(str); # Need improved word wrapping
+use PostScript::File 2.20 qw(str); # Need use_functions
 
 use namespace::autoclean -also => qr/^i[[:upper:]]/;
 
@@ -411,7 +411,7 @@ sub BUILD
         $class = "PostScript::ScheduleGrid::Style::$class"
             unless $class =~ s/^=//;
 
-        Class::MOP::load_class($class);
+        require_module($class);
 
         confess("$class does not do PostScript::ScheduleGrid::Role::Style")
             unless $class->DOES('PostScript::ScheduleGrid::Role::Style');
@@ -470,45 +470,6 @@ sub _ps_functions
   stroke
 } def
 
-%---------------------------------------------------------------------
-% Set the color:  RGBarray|BWnumber setColor
-
-/setColor
-{
-  dup type (arraytype) eq {
-    % We have an array, so it's RGB:
-    aload pop
-    setrgbcolor
-  }{
-    % Otherwise, it must be a gray level:
-    setgray
-  } ifelse
-} bind def
-
-%---------------------------------------------------------------------
-% Print text centered at a point:  X Y STRING showcenter
-%
-% Centers text horizontally
-
-/showcenter
-{
-  newpath
-  0 0 moveto
-  % stack X Y STRING
-  dup 4 1 roll                          % Put a copy of STRING on bottom
-  % stack STRING X Y STRING
-  false charpath flattenpath pathbbox   % Compute bounding box of STRING
-  % stack STRING X Y Lx Ly Ux Uy
-  pop exch pop                          % Discard Y values (... Lx Ux)
-  add 2 div neg                         % Compute X offset
-  % stack STRING X Y Ox
-  0                                     % Use 0 for y offset
-  newpath
-  moveto
-  rmoveto
-  show
-} def
-
 %---------------------------------------------------------------------
 % Print the date, times, resource names, & exterior grid:
 %
@@ -527,8 +488,8 @@ sub _ps_functions
   -$half_width $title_width
   % stack (TIME XPOS)
   {
-    dup %{$grid_height - $line_height + $title_baseline} 3 index showcenter
-    $title_baseline 3 -1 roll showcenter
+    dup %{$grid_height - $line_height + $title_baseline} 3 index showCenter
+    $title_baseline 3 -1 roll showCenter
   } for
 
 END PS INIT
@@ -662,7 +623,8 @@ sub _run
   $ps->need_resource(font => $self->cell_font, $self->heading_font,
                      $self->title_font);
 
-  $ps->add_function($self->_ps_functions);
+  $ps->use_functions(qw(setColor showCenter));
+  $ps->add_procset($self->_ps_functions);
 
   { my $setup = <<'END SETUP';
 /CellFont   /$cell_font-iso    findfont  $cell_font_size    scalefont  def
@@ -887,9 +849,9 @@ PostScript::ScheduleGrid - Print a schedule in a grid format
 
 =head1 VERSION
 
-This document describes version 0.03 of
-PostScript::ScheduleGrid, released May 11, 2013
-as part of PostScript-ScheduleGrid version 0.03.
+This document describes version 0.04 of
+PostScript::ScheduleGrid, released December 7, 2013
+as part of PostScript-ScheduleGrid version 0.04.
 
 =head1 SYNOPSIS
 
@@ -1294,7 +1256,7 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-ScheduleGrid >>.
 
 You can follow or contribute to PostScript-ScheduleGrid's development at
-L<< http://github.com/madsen/postscript-schedulegrid >>.
+L<< https://github.com/madsen/postscript-schedulegrid >>.
 
 =head1 COPYRIGHT AND LICENSE
 
